@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -39,19 +39,20 @@ FindDialog::FindDialog(QWidget *parent)
     findButton = new QPushButton(tr("&Find"));
     findButton->setDefault(true);
 
-    closeButton = new QPushButton(tr("Close"));
-
     moreButton = new QPushButton(tr("&More"));
     moreButton->setCheckable(true);
     moreButton->setAutoDefault(false);
 
+    buttonBox = new QDialogButtonBox(Qt::Vertical);
+    buttonBox->addButton(findButton, QDialogButtonBox::ActionRole);
+    buttonBox->addButton(moreButton, QDialogButtonBox::ActionRole);
+
     extension = new QWidget;
 
     wholeWordsCheckBox = new QCheckBox(tr("&Whole words"));
     backwardCheckBox = new QCheckBox(tr("Search &backward"));
     searchSelectionCheckBox = new QCheckBox(tr("Search se&lection"));
 
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
     connect(moreButton, SIGNAL(toggled(bool)), extension, SLOT(setVisible(bool)));
 
     QVBoxLayout *extensionLayout = new QVBoxLayout;
@@ -71,16 +72,10 @@ FindDialog::FindDialog(QWidget *parent)
     leftLayout->addWidget(fromStartCheckBox);
     leftLayout->addStretch(1);
 
-    QVBoxLayout *rightLayout = new QVBoxLayout;
-    rightLayout->addWidget(findButton);
-    rightLayout->addWidget(closeButton);
-    rightLayout->addWidget(moreButton);
-    rightLayout->addStretch(1);
-
     QGridLayout *mainLayout = new QGridLayout;
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
     mainLayout->addLayout(leftLayout, 0, 0);
-    mainLayout->addLayout(rightLayout, 0, 1);
+    mainLayout->addWidget(buttonBox, 0, 1);
     mainLayout->addWidget(extension, 1, 0, 1, 2);
     setLayout(mainLayout);
 
