@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -74,12 +74,6 @@ GLWidget::~GLWidget()
 
 void GLWidget::initializeGL()
 {
-    glMatrixMode(GL_PROJECTION);
-    glLoadIdentity();
-
-    glFrustum(-1, 1, -1, 1, 10, 100);
-    glTranslatef(-0.5f, -0.5f, -0.5f);
-    glTranslatef(0.0f, 0.0f, -15.0f);
     glMatrixMode(GL_MODELVIEW);
 
     glEnable(GL_CULL_FACE);
@@ -101,6 +95,12 @@ void GLWidget::initializeGL()
 void GLWidget::resizeGL(int w, int h)
 {
     glViewport(0, 0, w, h);
+    glMatrixMode(GL_PROJECTION);
+    glLoadIdentity();
+    float aspect = w/(float)(h ? h : 1);
+    glFrustum(-aspect, aspect, -1, 1, 10, 100);
+    glTranslatef(-0.5f, -0.5f, -0.5f);
+    glTranslatef(0.0f, 0.0f, -15.0f);
 }
 
 void GLWidget::paintGL()
