@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -30,6 +30,8 @@
 #include <QString>
 
 class QCheckBox;
+class QDialogButtonBox;
+class QLabel;
 class QLineEdit;
 class QTableWidget;
 class QTextEdit;
@@ -46,7 +48,7 @@ public slots:
     void verify();
 
 public:
-    QList<QPair<QString,int> > orderItems();
+    QList<QPair<QString, int> > orderItems();
     QString senderName() const;
     QString senderAddress() const;
     bool sendOffers();
@@ -54,11 +56,14 @@ public:
 private:
     void setupItemsTable();
 
+    QLabel *nameLabel;
+    QLabel *addressLabel;
     QCheckBox *offersCheckBox;
     QLineEdit *nameEdit;
     QStringList items;
     QTableWidget *itemsTable;
     QTextEdit *addressEdit;
+    QDialogButtonBox *buttonBox;
 };
 
 #endif
