@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -26,6 +26,7 @@
 
 #include <QDialog>
 
+class QDialogButtonBox;
 class QPushButton;
 class QSqlTableModel;
 
@@ -43,6 +44,7 @@ private:
     QPushButton *submitButton;
     QPushButton *revertButton;
     QPushButton *quitButton;
+    QDialogButtonBox *buttonBox;
     QSqlTableModel *model;
 };
 
