@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -28,9 +28,10 @@
 #include <QMap>
 #include <QStringList>
 
+class QAbstractButton;
 class QCheckBox;
+class QDialogButtonBox;
 class QGroupBox;
-class QPushButton;
 class MainWindow;
 
 class LanguageChooser : public QDialog
@@ -55,9 +56,9 @@ private:
     QColor colorForLanguage(const QString &language);
 
     QGroupBox *groupBox;
-    QPushButton *showAllButton;
-    QPushButton *hideAllButton;
-    QPushButton *closeButton;
+    QDialogButtonBox *buttonBox;
+    QAbstractButton *showAllButton;
+    QAbstractButton *hideAllButton;
     QMap<QCheckBox *, QString> qmFileForCheckBoxMap;
     QMap<QCheckBox *, MainWindow *> mainWindowForCheckBoxMap;
 };
