@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -23,12 +23,23 @@
 
 #include <QtGui>
 
+#if defined(Q_WS_X11)
+#include <QTime>
+#include <private/qt_x11_p.h>
+#endif
+
 #include "displayshape.h"
 #include "displaywidget.h"
 
 DisplayWidget::DisplayWidget(QWidget *parent)
     : QWidget(parent)
 {
+#if defined(Q_WS_X11)
+    frameTime = 0;
+    avgRate = 0;
+    numFrames = 0;
+    testDrawSpeed = true;
+#endif
     empty = true;
     emptying = false;
 
@@ -114,14 +125,52 @@ void DisplayWidget::mousePressEvent(QMouseEvent *event)
 
 void DisplayWidget::paintEvent(QPaintEvent *event)
 {
+#if defined(Q_WS_X11)
+    QTime renderTime;
+    if (testDrawSpeed)
+        renderTime.restart();
+#endif
+
     QPainter painter;
     painter.begin(this);
     painter.fillRect(event->rect(), Qt::white);
-    foreach (DisplayShape *shape, shapes)
-        shape->paint(&painter);
+    foreach (DisplayShape *shape, shapes) {
+        if (shape->rect().intersects(event->rect()))
+            shape->paint(&painter);
+    }
     painter.end();
+
+#if defined(Q_WS_X11)
+    if (testDrawSpeed) {
+        numFrames++;
+        frameTime += renderTime.elapsed();
+        avgRate = frameTime/numFrames;
+        if (numFrames > 20) {
+            testDrawSpeed = false;
+            if (avgRate > 50 && X11->use_xrender)
+                QTimer::singleShot(0, this, SLOT(toggleXRender()));
+        }
+    }
+#endif
 }
 
+#if defined(Q_WS_X11)
+void DisplayWidget::toggleXRender()
+{
+    timer.stop();
+    int result = QMessageBox::question(this,
+                                       QObject::tr("Disable XRender?"),
+                                       QObject::tr("Your XRender implementation does not appear to be accelerated.\n"
+                                                   "This may cause this demo to run very slowly.\n"
+                                                   "Do you wish to turn XRender support off in this demo to improve\n"
+                                                   "the frame rate?"),
+                                       QMessageBox::Yes|QMessageBox::No);
+    if (result == QMessageBox::Yes)
+        X11->use_xrender = false;
+    enableUpdates();
+}
+#endif
+
 void DisplayWidget::reset()
 {
     if (emptying)
@@ -155,7 +204,7 @@ int DisplayWidget::shapesCount() const
 void DisplayWidget::enableUpdates()
 {
     if (!timer.isActive())
-        timer.start(50, this);
+        timer.start(25, this);
 }
 
 void DisplayWidget::timerEvent(QTimerEvent *event)
