@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -45,9 +45,6 @@ public:
     static bool isSupportedType(QVariant::Type type);
     static QString displayText(const QVariant &value);
 
-private slots:
-    void commitAndCloseEditor();
-
 private:
     mutable QRegExp boolExp;
     mutable QRegExp byteArrayExp;
