@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2004-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2004-2006 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -21,10 +21,9 @@
 **
 ****************************************************************************/
 
-#include <QApplication>
+#include <QtGui>
 
 #include <stdlib.h>
-#include <time.h>
 
 #include "tetrixwindow.h"
 
@@ -33,6 +32,6 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
     TetrixWindow window;
     window.show();
-    srand(time(0));
+    qsrand(QTime(0,0,0).secsTo(QTime::currentTime()));
     return app.exec();
 }
